@@ -8,6 +8,18 @@ def millisecond_stamp_to_datetime(milliseconds: int):  # ? As much as i would li
     seconds = int("".join([x for x in milliseconds if x.isdigit()])) / 1000  # Remove the "/Date(...)/" and convert to seconds
     return dt.datetime.fromtimestamp(seconds) + dt.timedelta(hours=1)  # Add 1 Hour Since TCR is off by 1 hour
 
+def datetime_to_string(date: dt.datetime):
+    """
+    ### Converts a datetime object to a string
+
+        Parameters:
+            date: The datetime object to convert
+
+        Returns:
+            The datetime object as a string
+    """
+    return date.strftime("%Y-%m-%dT%H:%M:%S.%f")
+
 def page_count(recordCount, pageSize):
     """
     ### Finds the number of pages needed to display all records.
